// 
// Copyright (C) 2009, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//
#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A reference sample demonstrating the more common DateTime properties and methods.
    /// </summary>
    [Description("A reference sample demonstrating the more common DateTime properties and methods.")]
    public class SampleDateTimeFunctions : Indicator
    {
        #region Variables
		private DateTime 	myDateTime; 									// This variable holds the primary DateTime object we'll be working with.
		private DateTime 	myDateTimePlusSome;								// We'll add the TimeSpan below to the original myDateTime to get this time
		private DateTime 	now; 											// This variable is declared here, but has no value until assigned below.
		private TimeSpan 	threeMinutesTwoSeconds = new TimeSpan(0, 3, 2); // This TimeSpan structure's duration is 3 minutes and 2 seconds.
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar == 0)
			{
				// This line of code prints a blank line in the output window, and is used to keep the output organized.
				Print("");
				
				
				// Clear the output window, as this is a print-only sample.
				ClearOutputWindow();
				
				
				/* Set a string that represents the format we'd like to use to print our DateTimes.
				   An extensive list of formatting can be found at http://www.geekzilla.co.uk/View00FF7904-B510-468C-A2C8-F859AA20581F.htm
				   This specific format reads [month/day/year hour:minute:second AM/PM] (with two digits for milliseconds). */
				string format = "MM/dd/yyyy HH:mm:ss tt";
				
				// Specify a date and time in string format to parse.
				string dateTimeToParse = "07/29/09 14:30:00";
				
				/* Try to parse that date and time. The "out" in the arguments means that variable is where the output should go to.
				   DateTime.TryParse returns either true or false, so the below code really means if (true) print "successful" else print "unsuccessful". */
				if (DateTime.TryParse(dateTimeToParse, out myDateTime))
					Print("Parsed successfully:\t" + myDateTime);
				else
					Print("Unable to understand DateTime input.");
				
				
				
				// After parsing, print different formats of the same DateTime
				Print("");
				Print("different formatting of the same DateTime");
				Print(myDateTime.ToString("yyyy-MM-dd HH:mm:ss"));
				Print(myDateTime.ToString("dddd MMMM dd yyyy, hh:mm:ss tt"));
				Print(myDateTime.ToString("yyyyMMdd HHmmssfff"));
				
				// Here, the print format is taken as the variable we set above.
				Print(myDateTime.ToString(format));

				// It is also possible to access the DateTime structure's properties directly.
				Print(myDateTime.Month.ToString() + "/"
					+ myDateTime.Day.ToString() + "/"
					+ myDateTime.Year.ToString() + " "
					+ myDateTime.Hour.ToString() + ":"
					+ myDateTime.Minute.ToString() + ":"
					+ myDateTime.Second.ToString());
				
				
				
				// Get the current time from PC's clock and save that value to the variable 'now'.
				Print("");				
				now = DateTime.Now;
				
				// Print that 'now' value
				Print("The time now:\t" + now.ToString(format));
				
				
				
				// Add time to the myDateTime DateTime object via a TimeSpan object and save the result in myDateTimePlusSome
				Print("");
				
				// Add the TimeSpan object
				myDateTimePlusSome = myDateTime.Add(threeMinutesTwoSeconds);
				
				// Print the current value of myDateTime
				Print("myDateTime = " + myDateTime.ToString(format));
				
				// myDateTimePlusSome is now equal to 07/29/2009 14:33:02 PM.
				Print("myDateTime + 3 minutes and 2 seconds = " + myDateTimePlusSome.ToString(format));
				
				
				
				// Add time to the myDateTime DateTime object via the other methods
				Print("");
				
				// Print the current value of myDateTime
				Print("myDateTime = " + myDateTime.ToString(format));
				
				// Add 5 minues and 4 seconds to myDateTime
				myDateTime = myDateTime.AddMinutes(5);
				myDateTime = myDateTime.AddSeconds(4);
				
				// myDateTime is now equal to 07/29/2009 14:35:04 PM.
				Print("myDateTime after adding 5 minutes and 4 seconds = " + myDateTime.ToString(format));
				
				
			
				/* Compare two DateTime objects, myDateTime and myDateTimePlusSome. The values for each DateTime object are in the comments above.
				   DateTime.Compare returns -1, 0 or 1, depending on the relationship of the two DateTime objects. */
				Print("");
				int result = (DateTime.Compare(myDateTime, myDateTimePlusSome));
				string relationship;
				
				if (result < 0)
					relationship = "is earlier than";
				else if (result > 0)
					relationship = "is later than";
				else
					relationship = "is the same time as";
				
				// Print the results.
				Print(String.Format("{0} {1} {2}", myDateTime, relationship, myDateTimePlusSome));
				
			}
        }

        #region Properties
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleDateTimeFunctions[] cacheSampleDateTimeFunctions = null;

        private static SampleDateTimeFunctions checkSampleDateTimeFunctions = new SampleDateTimeFunctions();

        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        public SampleDateTimeFunctions SampleDateTimeFunctions()
        {
            return SampleDateTimeFunctions(Input);
        }

        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        public SampleDateTimeFunctions SampleDateTimeFunctions(Data.IDataSeries input)
        {

            if (cacheSampleDateTimeFunctions != null)
                for (int idx = 0; idx < cacheSampleDateTimeFunctions.Length; idx++)
                    if (cacheSampleDateTimeFunctions[idx].EqualsInput(input))
                        return cacheSampleDateTimeFunctions[idx];

            SampleDateTimeFunctions indicator = new SampleDateTimeFunctions();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.SetUp();

            SampleDateTimeFunctions[] tmp = new SampleDateTimeFunctions[cacheSampleDateTimeFunctions == null ? 1 : cacheSampleDateTimeFunctions.Length + 1];
            if (cacheSampleDateTimeFunctions != null)
                cacheSampleDateTimeFunctions.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheSampleDateTimeFunctions = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleDateTimeFunctions SampleDateTimeFunctions()
        {
            return _indicator.SampleDateTimeFunctions(Input);
        }

        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleDateTimeFunctions SampleDateTimeFunctions(Data.IDataSeries input)
        {
            return _indicator.SampleDateTimeFunctions(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleDateTimeFunctions SampleDateTimeFunctions()
        {
            return _indicator.SampleDateTimeFunctions(Input);
        }

        /// <summary>
        /// A reference sample demonstrating the more common DateTime properties and methods.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleDateTimeFunctions SampleDateTimeFunctions(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleDateTimeFunctions(input);
        }

    }
}
#endregion
